@@ -1,9 +1,9 @@
 ####**********************************************************************
 ####**********************************************************************
 ####
-####  SPIKE AND SLAB 1.1.4
+####  SPIKE AND SLAB 1.1.5
 ####
-####  Copyright 2010, Cleveland Clinic Foundation
+####  Copyright 2013, Cleveland Clinic Foundation
 ####
 ####  This program is free software; you can redistribute it and/or
 ####  modify it under the terms of the GNU General Public License
@@ -21,58 +21,39 @@
 ####  Boston, MA  02110-1301, USA.
 ####
 ####  ----------------------------------------------------------------
-####  Project Partially Funded By:
-####    --------------------------------------------------------------
-####    National Science Foundation, Grants DMS-0705037, DMS-0405675 and DMS-0405072
-####
-####    Hemant Ishwaran, Ph.D.
-####    Dept of Quantitative Health Sciences/Wb4
-####    Cleveland Clinic Foundation
-####    9500 Euclid Avenue
-####    Cleveland, OH 44195
-####
-####    email:  hemant.ishwaran@gmail.com
-####    phone:  216-444-9932
-####    URL:    www.bio.ri.ccf.org/Resume/Pages/Ishwaran/ishwaran.html
-####
-####
-####	J. Sunil Rao, Ph.D.
-####    Deparment of Biostatistics
-####    University of Miami
-####
-####    email: rao.jsunil@gmail.com
-####
-####    --------------------------------------------------------------
-####    Case Western Reserve University/Cleveland Clinic  
-####    CTSA Grant:  XX1 RR000000, National Center for
-####    Research Resources (NCRR), NIH
-####
+####  Written and Developed by:
 ####  ----------------------------------------------------------------
-####  Written by:
-####    --------------------------------------------------------------
 ####    Hemant Ishwaran, Ph.D.
-####    Dept of Quantitative Health Sciences/Wb4
-####    Cleveland Clinic Foundation
-####    9500 Euclid Avenue
-####    Cleveland, OH 44195
+####    Director of Statistical Methodology
+####    Professor, Division of Biostatistics
+####    Clinical Research Building, Room 1058
+####    1120 NW 14th Street
+####    University of Miami, Miami FL 33136
 ####
 ####    email:  hemant.ishwaran@gmail.com
-####    phone:  216-444-9932
-####    URL:    www.bio.ri.ccf.org/Resume/Pages/Ishwaran/ishwaran.html
-####
+####    URL:    http://web.ccs.miami.edu/~hishwaran
+####    --------------------------------------------------------------
+####    J. Sunil Rao, Ph. D.
+####    Professor and Director of the Division of Biostatistics, 
+####    Department of Epidemiology & Public Health
+####    Clinical Research Bldg, R-669
+####    1120 NW 14th Street, Room 1056
+####    Miami, FL 33136
+####    email:  rao.jsunil@gmail.com
+####    URL:    http://biostat.med.miami.edu/people/primary-faculty/sunil-rao
 ####  ----------------------------------------------------------------
 ####  Maintained by:
 ####    Udaya B. Kogalur, Ph.D.
-####    Dept of Quantitative Health Sciences/Wb4
+####    Adjunct Staff
+####    Dept of Quantitative Health Sciences
 ####    Cleveland Clinic Foundation
 ####    
-####    Kogalur Shear Corporation
+####    Kogalur & Company, Inc.
 ####    5425 Nestleway Drive, Suite L1
 ####    Clemmons, NC 27012
 ####
-####    email:  kogalurshear@gmail.com
-####    phone:  919-824-9825
-####    URL:    www.kogalur-shear.com
+####    email:  ubk@kogalur.com
+####    URL:    http://www.kogalur.com
 ####    --------------------------------------------------------------
 ####
 ####**********************************************************************
@@ -238,8 +219,8 @@ if (bigp.smalln) {
 #  Save sufficient statistics for original X and Y
 Y.org.mean <- mean.center(Y.org, center = intercept)
 Y.center <- Y.org - Y.org.mean
-X.org.sd <- as.real(c(apply(X.org, 2, sd.center, center = center)))
-X.org.mean <- as.real(apply(X.org, 2, mean.center, center = center))
+X.org.sd <- as.double(c(apply(X.org, 2, sd.center, center = center)))
+X.org.mean <- as.double(apply(X.org, 2, mean.center, center = center))
 
 ### ---------------------------------
 ### Define working X matrix
